

This document is an addendum for DB, The Atari Debugger, release 2, version
90/01/24.  It describes DB Release 3, 91/06/27.

NEW FEATURES:

	Expressions: the LISP-style prefix expressions like "(+ 1 2)" are
dead; this version of the debugger uses infix expressions like "(1 + 2)"
instead.  See the detailed documentation on infix expressions later in this
document.

	Flip: when single-machine debugging, the debugger can allocate its
own text output screen, and leave the client's screen uncluttered. This is
enabled with the "-2" option on db's command line.  When the client is
running, the client screen is visible.  When the debugger is running, the
debugger screen is visible.  The "flip" command with no arguments will
display the client screen until you hit a key.  With an argument, "flip"
will display the client screen for that number of milliseconds (to the
resolution of the "sleep" command).  Hitting a key ends the sleep and the
flip.  The dual-screen feature is to be considered experimental.  It is not
perfect.  If it doesn't work for you, don't use it; use serial-port or
remote debugging instead.  A "flip" command used when the debugger was not
started with -2 on its command line has no effect.

	Symbols: DB now supports GST-format symbols (also used by Lattice C
from HiSoft).  In this format, symbols can be up to 22 characters long. The
symbol table looks like an Alcyon symbol table, with 14-byte symbol
entries, except that when the $0048 bits are set in a symbol's type, the
next 14-byte entry is actually an extension of the symbol's name.  A new
variable, symsearch, contains a bitmap of methods to use to look up symbol
names.  It is set automatically based on the types of symbol tables
encountered by the "getsym" and "exec" commands, including the implicit
"exec" when a program name is supplied on the debugger command line.

	VALUE	TYPE	METHOD 

	0001	GST	Truncate to 22 chars; failing that, prepend '_' and
			use 21 chars; failing that, prepend '@' and use 21
			chars.

	0002	MWC	Truncate to 16 chars; failing that, append '_'.

	0004	ALC	Truncate to 8 chars; failing that, prepend '_' and
			use 7 chars.

	Print: the print command is different.  See the full documentation
of the print command later in this document.  Mainly, the difference
is that you have to specify a conversion before each argument that
you want printed as a number.  Without a conversion arguments are
printed verbatim.  Also, quoted strings can be used to output arguments
with unbalanced parentheses and multiple spaces, and you can inhibit
the space between arguments.  Echo is now just an alias for print.

	Help by topics: the "help" command now takes an argument.  With no
argument it tells you how to get more help.  The special words "commands,"
"variables," "expressions," and "printargs" give help on those topics. 
Other words give help on commands and variables which contain that string. 
For example, "help sym" gives help on the "sym," "getsym," and "nosym"
commands and the "symsearch" variable.

	Load: the load command now searches the directory named in the
environment variable $HOME if the file is not found in the current
directory.

	Messages: a client can send a message to the debugger which causes
the debugger to execute a command.  If the message type is 0xF100, the
message argument vector is taken to be a pointer to client memory, and the
null-terminated string found there is read and executed as if by the
"indirect" command.  If this command ends with a "trace/go" command or,
more reliably, with "defer g" then the client will continue to run after
the command has executed, with no user intervention.




	A dump, set, or list of zero bytes (i.e. "d .label[0]") will not
produce any output, but will cause the default start of the next
dump/set/list command to be set.

	Tabs and spaces both delimit words in commands.  Previously, only
spaces were recognized in some places.  It is still the case that when you
hit tab on the keyboard you get a space.

	Sleep: the "sleep" command takes one argument, and sleeps for that
many milliseconds.  The resolution is coarse: it uses the 200Hz timer, and
the actual sleep time is rounded off to 5ms and is granular.  The sleep can
be interrupted by hitting a key.  Hitting ^C will stop the sleep and abort
all the way back to the debugger prompt.

	Memory checkpoints: the command "m .label.w" now results in the
same checkpoint as "m .label.w != old" rather than "m .label[2]" which is
slower and not completely accurate.

	Read and write: when not remote debugging, the read and write
commands now use a single GEMDOS call to transfer data.  This is
significantly faster than passing the data through the debugger-to-stub
pipeline.

	Set: in the interactive mode of the "s" (set) command, a line
consisting only of the up-arrow ("^") causes the memory pointer to back up
to the previous byte/word/long and give you another chance at it.  A line
consisting only of a less-than sign ("<") causes the memory pointer to stay
where it is, and re-read the memory.  These can be useful for poking around
with I/O devices and memory locations which change asynchronously (i.e. at
interrupt time or due to hardware state changes).  These are most usefully
bound to keys, ^P (for previous) might be bound to "^\r" and ^R (for
"repeat") might be bound to "<\r" for convenient access.

	Gag: gags now nest.  "gag on" sets gagging one level deep. "gag
off" sets it to zero (no gagging).  "gag push" pushes one gag level, and
"gag pop" pops a gag level.  The result is that a procedure or alias can
use "gag push" and "gag pop" around something whose output is not wanted,
and that alias can be used inside another "gag push" with proper nesting.

	Transcript: when the transcript buffer fills up, it is written to
disk.  The file is now opened, written, and closed, rather than staying
open as long as the transcript is active.  This means it does not matter
when you open or close the transcript file in relation to executing and
terminating programs.

	New variable: "eightbit" is a variable which controls the printing
of characters which have their high bits set in the ASCII output of the "d"
(dump) command.  When eightbit is zero, characters in the range 127-255 are
displayed as '.'; when nonzero they are output normally.  This variable is
set initially based on the 'x' modifier on the -b, -s, -m, and -g
command-line options.


BUG FIXES:

	Disassembly of the cas, cas2, pmove, and movec instructions was
sometimes wrong.  Also, the $x(PC,Xn) addressing mode disassembled wrong
(the offset $x was off by two bytes).

	A nonempty line containing nothing but whitespace, either from the
console or from a script file, is no longer considered an error.

	An "exit" command in a script file does not cause an error message
any more.

	The command "s 100[100] 1 2" has always been invalid, since the
"fill a range of memory" form of "set" only uses one value argument after
the range argument.  It is now flagged as an error.  In addition, the "fill
a range of memory" form generated some output to the screen; this has been
removed.

	The "v" (verbose-trace) command caused a bus error when given an
argument other than 'x' or 'w'.  Now a numerical argument is correctly
interpreted as the number of instructions to trace verbosely.

MISCELLANY:

	The warning about duplicate globals is gone.  It was annoying to
see that when the same script file containing global variables was loaded
twice.



Documentation for the debugger's infix expression analyzer.

As of Release 3, the debugger sports a C-style expression analyzer.  Any
place in a command where a number can appear, an expression can also be
used.  The old LISP-style expressions no longer work.

The operators you can use in expressions are all as in C:

	+ - * / %  (arithmetic add, subtract, multiply, divide, remainder)
	& | ^ ~			   (bitwise and, or, exclusive-or, invert)
	&& || !					    (logical and, or, not)
	== != > < >= <= 		    (relational operators, signed)
	u> u< u>= u<=			  (relational operators, unsigned)
	>> <<					     (bit-shift operators)
	= += -= *= /= %= ^= &= |= >>= <<=	    (assignment operators)
	?:					(the conditional operator)

In addition, some "function calls" are available: peek(exp) returns the
value of the byte at address 'exp' in client memory.  wpeek(exp) returns
the word, and lpeek(exp) returns the long.  speek(exp) and swpeek(exp)
return the byte and word sign-extended into a long.

Parentheses can be used for grouping.  Also, since spaces separate
arguments in commands, you need to use parentheses to set off an expression
containing spaces as a single argument.  For example:

	l .func + 10

is the "list" command with three arguments: the value of .func, the
nonsensical argument '+', and the number $10.  The following two lines both
do what you expect: list starting at offset $10 in .func; the first because
there are no spaces in the argument and the second because the expression
is set off with parentheses:

	l .func+10
	l (.func + 10)

Names of machine registers, stub variables, global variables and local
variables (when in scope) can all be used and assigned to in expressions.
To use program symbols, use a dot as a prefix: ".start" means "the value of
the program symbol 'start'" (NOT the value found at that address).

In an expression, a word like "feed" might be interpreted as either a
variable name or a hex number.  Words are scanned for meaning in that
order.  Prefix with a zero ('0') or a dollar-sign ('$') to force
interpretation as a hex number ("0feed" or "$feed"), or a backquote ('`')
to force interpretation as a variable ("`feed").  In addition, ^^d0 is the
address of d0.l in the stub's memory.

Unlike C, the && and || and ?: operators always evaluate all their
operands.  An example use of the conditional operator: 
	var = (exp1 ? exp2 : exp3)
means, "If exp1 is true, set var to exp2, else set var to exp3."



To just "do math" at the debugger command prompt you can give a command
like "3 + 3" and see the answer.  The expression may include spaces, but if
the first part of the expression looks like a command, it will not do what
you expect: the command "swpeek(.label)" is taken to be the 's' command
with the 'w' modifier and "peek(.label)" as the argument, rather than being
taken as an expression which would return the sign-extended word found at
"label."

To set off expressions used as commands, put parens around them: as a
command, "d0" means "dump starting at zero" but "(d0)" means "print the
value of the register d0."  Similarly, "t0=2" is the "t" (trace) command
with the nonsensical argument "0=2" while "(t0=2)" will assign the value 2
to the variable t0.

As before, the special variable "$" represents the value of the last of
these expression-commands.  These expression-commands normally print the
result in hex, decimal, and binary, but if there are any assignment
operators then the answer isn't printed.  Thus, "(var += 6)" is a legal
command which increments var by 6 and assigns the answer to $, but does not
print the answer.  This is the most natural way to assign and change values
of variables in scripts; the "set" and "x" commands can also be used, but
they are now obsolete.

Caveat: an assignment like "(t0 = 3 x)" will in fact assign 3 to the
variable t0 before jumping out with a parse error.

Also, the prefix for binary constants is now the number sign ('#'), and
octal constants are no longer available.  The at-sign ('@') is still the
prefix for decimal constants, and the dollar-sign ('$') can still be used
as a prefix for hex constants, though no prefix at all also means hex.






THE PRINT COMMAND (NEW FUNCTIONALITY AS OF RELEASE 3)

The print command prints (most of) its arguments to the screen.  Arguments
which begin with a dash are switches, and modify what gets printed rather
than appearing in the output.  Without any conversion switches the
arguments are printed verbatim, so the "echo" command is now just an alias
for print.

Normally, output is printed in "regular" (not inverse) video, and after
each argument a single space appears in the output, and a newline is output
after the last argument.  The following "modifier" switches change this
default behavior:

	MODIFIER	MEANING
	   -n		don't output a newline at the end of the line.
	   -i		enter inverse video until -r or end of line.
	   -r		regular video: cancel inverse video.
	   -t		do not output a space between arguments.
	   -T		do output a space between arguments.

The -t switch inhibits spaces starting with the one after the NEXT
argument; see the examples.

Other switches, called conversions, indicate that the next argument is to
be interpreted as an expression, and tell how to output the result.

	CONVERSION	OUTPUT RESULT AS...
	    -x		hex
	    -d		decimal
	    -o		octal
	    -b		binary
	    -c		a character (low 8 bits of result)
	    -s		string (see below)

After the conversion character you can specify a field width.  The output
will be padded with leading spaces to that width.  If the first character
of the field width is a zero, the output will be padded with leading zeros
to that width.
 
The -s conversion means "string:" the result of evaluating the next
argument is taken to be an address in client memory, and a string is read
from there up to a null byte or the maximum field width.  If the field
width starts with a zero, the string is padded with trailing spaces to that
width.

The field width and zero-fill flags are ignored for the -c conversion. If
you actually want to print something that starts with a dash or contains
multiple spaces or unbalanced parentheses, use a string (that is, surround
the argument with single- or double-quotes).

While this command will probably never go away, a future release of the
debugger is likely to have something more closely resembling printf.




PRINT COMMAND EXAMPLES

	command:  print two plus two is -d 2+2 and 4 + 4 is -d (4 + 4)
	output:	  two plus two is 4 and 4 + 4 is 8

		(As elsewhere in the debugger, if an expression
		contains spaces you must wrap it in parentheses.)

	command:  print sixteen hex is -t $ -x 10 .
	output:	  sixteen hex is $10.

		(The -t modifier prevents the spaces between arguments.
		It inhibits spaces starting with the one that would come
		after the NEXT argument, so in this case there IS a space
		between "is" and "$")

	command:  print -t "funcall(" -x8 lpeek(sp+4) , -x08 lpeek(sp+8) ")"
	output:	  funcall(  12D342,00285F20)

		(more fun with -t, field width, and zero-filled field
		width: there are no "automatic" spaces between args because
		of -t; the first arg is space-padded to 8 chars, and the
		second is zero-padded to 8 chars.  Also, the presence of
		unbalanced parentheses means they have to be in strings.)

	command:  print test "-   (a  '  [b" test
	output:   test -   (a  '  [b test

		(If you want a leading dash, multiple spaces or unbalanced
		parentheses or quotes, you need to quote the argument.)

	command:  print value: -d(wpeek(.width)) .value str: -s0@32 .string !
	output:	  value:    321 str: abcde                            !

		(You can compute the field width; it can be any expression.
		If you also want to specify "zero-filled" you put the zero
		before the expression.  "Zero-filled" for strings really
		means "padded with trailing spaces."
