*___________________________________________________________________________
***  Magic Numbers

resmagic        ==      $31415926       ; validates 'resvalid'
diagmagic       ==      $fa52235f       ; validate diagnostic cartridge
apmagic         ==      $abcdef42       ; validate application cartridge
memmagic        ==      $752019f3       ; validates 'memvalid'
memmag2         ==      $237698aa       ; validates 'memval2'
memmag3         ==      $5555aaaa       ; validates 'memval3'
bootmagic       ==      $1234           ; magic checksum for boot sector
resresval       ==      $12123456       ; validates reset resident routines
resreschk	==	$5678		; reset resident routine checksum
osmagic		==	$87654321	; validates end_os and exec_os
AHDImagic	==	$41484449	; AHDI 3+ magic number ('AHDI')

*___________________________________________________________________________
***  RAM configuration equates

bank1           ==      $200000         ; address of 2Mb second bank
twomb           ==      1024*2048       ; two megabytes
one28           ==      $20000          ; 128K

*___________________________________________________________________________
*** ROM addresses

cartbase        ==      $fa0000         ; start of cartridge ROM
cart2base	==	$fb0000		; second 64K bank of cartridge
oldroms		==	$fc0000		; ST TOS ROM address
newroms		==	$e00000		; STE & TT TOS ROM address

*___________________________________________________________________________
*** MMU

memconf         ==      $ffff8001       ; memory controller

*___________________________________________________________________________
*** Shifter

dbaseh          ==      $ffff8201       ; display base high
dbasel          ==      $ffff8203       ; display base low

vcounthi        ==      $ffff8205       ; video address pointer high
vcountmid       ==      $ffff8207       ; video address pointer mid
vcountlow       ==      $ffff8209       ; video address pointer low

syncmode        ==      $ffff820a       ; video sync mode

color0          ==      $ffff8240       ; color palette #0
color1          ==      $ffff8242       ; color palette #1
color2          ==      $ffff8244       ; color palette #2
color3          ==      $ffff8246       ; color palette #3
color4          ==      $ffff8248       ; color palette #4
color5          ==      $ffff824a       ; color palette #5
color6          ==      $ffff824c       ; color palette #6
color7          ==      $ffff824e       ; color palette #7
color8          ==      $ffff8250       ; color palette #8
color9          ==      $ffff8252       ; color palette #9
color10         ==      $ffff8254       ; color palette #10
color11         ==      $ffff8256       ; color palette #11
color12         ==      $ffff8258       ; color palette #12
color13         ==      $ffff825a       ; color palette #13
color14         ==      $ffff825c       ; color palette #14
color15         ==      $ffff825e       ; color palette #15

shiftmd         ==      $ffff8260       ; video shift mode (resolution)

*___________________________________________________________________________
*** DMA chip

diskctl         ==      $ffff8604       ; disk controller data access
fifo            ==      $ffff8606       ; DMA mode control
dmahigh         ==      $ffff8609       ; DMA base high
dmamid          ==      $ffff860b       ; DMA base medium
dmalow          ==      $ffff860d       ; DMA base low

*___________________________________________________________________________
*** GI ("psg") sound chip

giselect        ==      $ffff8800       ; (W) sound chip register select
giread          ==      $ffff8800       ; (R) sound chip read-data
giwrite         ==      $ffff8802       ; (W) sound chip write-data

*___________________________________________________________________________
*** 68901 ("mfp") sticky chip:

mfp             ==      $fffffa00       ; mfp base
gpip            ==      mfp+1           ; general purpose I/O
aer             ==      mfp+3           ; active edge reg
ddr             ==      mfp+5           ; data direction reg
iera            ==      mfp+7           ; interrupt enable A & B
ierb            ==      mfp+9
ipra            ==      mfp+$b          ; interrupt pending A & B
iprb            ==      mfp+$d
isra            ==      mfp+$f          ; interrupt inService A & B
isrb            ==      mfp+$11
imra            ==      mfp+$13         ; interrupt mask A & B
imrb            ==      mfp+$15
vr              ==      mfp+$17         ; interrupt vector base
tacr            ==      mfp+$19         ; timer A control
tbcr            ==      mfp+$1b         ; timer B control
tcdcr           ==      mfp+$1d         ; timer C & D control
tadr            ==      mfp+$1f         ; timer A data
tbdr            ==      mfp+$21         ; timer B data
tcdr            ==      mfp+$23         ; timer C data
tddr            ==      mfp+$25         ; timer D data
scr             ==      mfp+$27         ; sync char
ucr             ==      mfp+$29         ; USART control reg
rsr             ==      mfp+$2b         ; receiver status
tsr             ==      mfp+$2d         ; transmit status
udr             ==      mfp+$2f         ; USART data

*___________________________________________________________________________
*** 6850 registers

keyctl          ==      $fffffc00       ; keyboard ACIA control
keybd           ==      $fffffc02       ; keyboard data
midictl         ==      $fffffc04       ; MIDI ACIA control
midi            ==      $fffffc06       ; MIDI data

*___________________________________________________________________________
*** BLiTTER registers

halftone0       ==      $ffff8a00
halftone1       ==      $ffff8a02
halftone2       ==      $ffff8a04
halftone3       ==      $ffff8a06
halftone4       ==      $ffff8a08
halftone5       ==      $ffff8a0a
halftone6       ==      $ffff8a0c
halftone7       ==      $ffff8a0e
halftone8       ==      $ffff8a10
halftone9       ==      $ffff8a12
halftone10      ==      $ffff8a14
halftone11      ==      $ffff8a16
halftone12      ==      $ffff8a18
halftone13      ==      $ffff8a1a
halftone14      ==      $ffff8a1c
halftone15      ==      $ffff8a1e

src_xinc        ==      $ffff8a20       ; source x increment
src_yinc        ==      $ffff8a22       ; source y increment

src_addr        ==      $ffff8a24       ; source address low
*src_addrh      ==      $ffff8a26       ; source address high

endmask1        ==      $ffff8a28       ; endmask 1
endmask2        ==      $ffff8a2a       ; endmask 2
endmask3        ==      $ffff8a2c       ; endmask 3

dst_xinc        ==      $ffff8a2e       ; destination x increment
dst_yinc        ==      $ffff8a30       ; destination y increment

dst_addr        ==      $ffff8a32       ; destination address low
*dst_addrh      ==      $ffff8a34       ; destination address high

x_count         ==      $ffff8a36       ; x count
y_count         ==      $ffff8a38       ; y count

hop             ==      $ffff8a3a       ; half-tone operation
op              ==      $ffff8a3b       ; logical operation

hog             ==      $ffff8a3c
smudge          ==      $ffff8a3c
line_num        ==      $ffff8a3c       ; Busy,HOG,SMUDGE,line number
fxsr            ==      $ffff8a3d
nfsr            ==      $ffff8a3d
skew            ==      $ffff8a3d       ; FXSR,NFSR,SKEW

*___________________________________________________________________________
*** Realtime clock

rtonesec        ==      $fffffc21       ; one second (low 4 bits)
rttensec        ==      $fffffc23       ; ten seconds
rtonemin        ==      $fffffc25       ; one minute
rttenmin        ==      $fffffc27       ; ten minutes
rtonehour       ==      $fffffc29       ; one hour
rttenhour       ==      $fffffc2b       ; ten hours
rtweekday       ==      $fffffc2d       ; weekday
rtoneday        ==      $fffffc2f       ; one day
rttenday        ==      $fffffc31       ; ten days
rtonemnth       ==      $fffffc33       ; one month
rttenmnth       ==      $fffffc35       ; ten months
rtoneyear       ==      $fffffc37       ; one year
rtenteay        ==      $fffffc39       ; ten years

rtcntrl1        ==      $fffffc3b       ; control register 1
rtcntrl2        ==      $fffffc3d       ; control register 2
rtcntrl3        ==      $fffffc3f       ; control register 3

*___________________________________________________________________________
*** STE Controllers

buttons         ==      $ffff9200       ; fire buttons (low 4 bits of word)
sticks          ==      $ffff9202       ; joysticks

xpaddle0        ==      $ffff9210       ; X paddle 0
ypaddle0        ==      $ffff9212       ; Y paddle 0
xpaddle1        ==      $ffff9214       ; X paddle 1
ypaddle1        ==      $ffff9216       ; Y paddle 1

lightx          ==      $ffff9220       ; lightpen/gun X position
lighty          ==      $ffff9222       ; lightpwn/gun Y position

*___________________________________________________________________________
*** STE/TT Shifter

vbaselo         ==      $fffff20d       ; new low byte of video base address
linewid         ==      $ffff820f       ; offset to start of next line
hscroll         ==      $ffff8265       ; horizontal bit-wise scroll (STE)

*___________________________________________________________________________
*** DMA Sound Chip

SND             ==      $ffff8900       ; DMA sound chip control

SNDbasehi       ==      $ffff8902       ; RW frame base address (high)
SNDbasemid      ==      $ffff8904       ; RW frame base address (middle)
SNDbaselo       ==      $ffff8906       ; RW frame base address (low)

SNDcounthi      ==      $ffff8908       ; RO frame address counter (high)
SNDcountmid     ==      $ffff890a       ; RO frame address counter (middle)
SNDcountlo      ==      $ffff890c       ; RO frame address counter (low)

SNDendhi        ==      $ffff890e       ; RW frame end address (high)
SNDendmid       ==      $ffff8910       ; RW frame end address (middle)
SNDendlo        ==      $ffff8912       ; RW frame end address (low)

SNDmode         ==      $ffff8920       ; RW sound mode control

*___________________________________________________________________________
*** MICROWIRE Interface

MWDATA          ==      $ffff8922       ; MICROWIRE data register
MWMASK          ==      $ffff8924       ; MICROWIRE mask register

*___________________________________________________________________________
*** SFP004 68881 Floating Point Coprocessor

FPCIR           ==      $fffffa40       ; status register
FPCTL           ==      $fffffa42       ; control register
FPSAV           ==      $fffffa44       ; save register
FPREST          ==      $fffffa46       ; restore register
FPOPR           ==      $fffffa48       ; operation word register
FPCMD           ==      $fffffa4a       ; command register
FPRES           ==      $fffffa4c       ; reserved
FPCCR           ==      $fffffa4e       ; condition code register
FPOP            ==      $fffffa50       ; operand register

*___________________________________________________________________________
*** Processor Dump Area (CPU state is dumped here after an uncaught trap)

proc_lives      ==      $380                    ; lives if $12345678
proc_regs       ==      proc_lives+4            ; D0-D7/A0-A7
proc_pc         ==      proc_regs+$40           ; PC
proc_usp        ==      proc_pc+4               ; USP
proc_stk        ==      proc_usp+4              ; six words of stack


*___________________________________________________________________________
*** System Globals

etv_timer       ==      $400    ;  vector for timer interrupt chain
etv_critic      ==      $404    ;  vector for critical error chain
etv_term        ==      $408    ;  vector for process terminate
etv_xtra        ==      $40c    ;  5 reserved vectors
*               ==      $410
*               ==      $414
*               ==      $418
*               ==      $41c
memvalid        ==      $420    ;  indicates system state on RESET
memcntlr        ==      $424    ;  mem controller config nibble
resvalid        ==      $426    ;  validates 'resvector'
resvector       ==      $42a    ;  [RESET] bailout vector
phystop         ==      $42e    ;  physical top of RAM
_membot         ==      $432    ;  bottom of available memory
_memtop         ==      $436    ;  top of available memory
memval2         ==      $43a    ;  validates 'memcntlr' and 'memconf'
flock           ==      $43e    ;  floppy disk/FIFO lock variable
seekrate        ==      $440    ;  default floppy seek rate
_timr_ms        ==      $442    ;  system timer calibration (in ms)
_fverify        ==      $444    ;  nonzero: verify on floppy write
_bootdev        ==      $446    ;  default boot device
palmode         ==      $448    ;  nonzero ==> PAL mode
defshiftmd      ==      $44a    ;  default video rez (first byte)
sshiftmd        ==      $44c    ;  shadow for 'shiftmd' register
_v_bas_ad       ==      $44e    ;  pointer to base of screen memory
vblsem          ==      $452    ;  semaphore to enforce mutex in  vbl
nvbls           ==      $454    ;  number of deferred vectors
_vblqueue       ==      $456    ;  pointer to vector of deferred  vfuncs
colorptr        ==      $45a    ;  pointer to palette setup (or NULL)
screenpt        ==      $45e    ;  pointer to screen base setup (|NULL)
_vbclock        ==      $462    ;  count  of unblocked vblanks
_frclock        ==      $466    ;  count  of every vblank
hdv_init        ==      $46a    ;  hard disk initialization
swv_vec         ==      $46e    ;  video change-resolution bailout
hdv_bpb         ==      $472    ;  disk "get BPB"
hdv_rw          ==      $476    ;  disk read/write
hdv_boot        ==      $47a    ;  disk "get boot sector"
hdv_mediach     ==      $47e    ;  disk media change detect
_cmdload        ==      $482    ;  nonzero: load COMMAND.COM from boot
conterm         ==      $484    ;  console/vt52 bitSwitches (%%0..%%2)
* unused        ==      $485    ;  [unused, reserved]
trp14ret        ==      $486    ;  saved return addr for _trap14
criticret       ==      $48a    ;  saved return addr for _critic
themd           ==      $48e    ;  memory descriptor (MD)
_____md         ==      $49e    ;  (more MD)
savptr          ==      $4a2    ;  pointer to register save area
_nflops         ==      $4a6    ;  number of disks attached (0, 1+)
con_state       ==      $4a8    ;  state of conout() parser
save_row        ==      $4ac    ;  saved row# for cursor X-Y addressing
sav_context     ==      $4ae    ;  pointer to saved processor context
_bufl           ==      $4b2    ;  two buffer-list headers
_bufl1		==	$4b6	;  second buffer header
_hz_200         ==      $4ba    ;  200hz raw system timer tick
the_env         ==      $4be    ;  default environment string (four 0 bytes)
_drvbits        ==      $4c2    ;  bit vector of "live" block devices
_dskbufp        ==      $4c6    ;  pointer to 1K disk buffer
_autopath       ==      $4ca    ;  pointer to autoexec path (or NULL)
_vbl_list       ==      $4ce    ;  initial _vblqueue (to $4ee)
_prt_cnt        ==      $4ee    ;  screen-dump flag alias
_dumpflg        ==      $4ee    ;  screen-dump flag
_prtabt         ==      $4f0    ;  printer abort flag
_sysbase        ==      $4f2    ;  -> base of OS
_shell_p        ==      $4f6    ;  -> global shell info
end_os          ==      $4fa    ;  -> end of OS memory usage
exec_os         ==      $4fe    ;  -> address of shell to exec on startup
scr_dump        ==      $502    ;  -> screen dump code
prt_stat        ==      $506    ; printer status vector for hardcopy
prt_vec         ==      $50a    ; printer output vector for hardcopy
aux_stat        ==      $50e    ; vector for getting serial output status during hardcopy
aux_vec         ==      $512    ; vector for serial output of hardcopy
pun_ptr		==	$516	; pointer to AHDI 3+ data structure
memval3         ==      $51a    ; yet another memvalid (set after memclear)
bconstat_vec    ==      $51e    ; input status vectors for devices 0-7
bconin_vec      ==      $53e    ; input vectors for devices 0-7
bcostat_vec     ==      $55e    ; output status vectors for devices 0-7
bconout_vec     ==      $57e    ; output vectors for devices 0-7
longframe	==	$59e	; TOS 1.6+ long staceframe flag (68020/30)
_p_cookies      ==      $5a0    ; pointer to cookie jar
bell_hook       ==      $5ac    ; TOS 1.6+ bell vector
kcl_hook        ==      $5b0    ; TOS 1.6+ key click vector

dsb_10		==	$a06	; TOS 1.0 dsb
aseek_10	==	$a09	; TOS 1.0 drive A seek rate
bseek_10	==	$a0d	; TOS 1.0 drive B seek rate
dsb_12		==	$a4c	; TOS 1.2 dsb
aseek_12	==	$a4f	; TOS 1.2 drive A seek rate
bseek_12	==	$a53	; TOS 1.2 drive B seek rate

p_run_10	==	$602c	; non-Spanish TOS 1.0 pointer to _run
p_run_SPA_10	==	$873c	; Spanish TOS 1.0 pointer to _run

*----------------------------------------
*                                       :
*       PATCH AREA, $580..$7FF          :
*                                       :
*       This space reserved for         :
*       future RAM-loaded fixes         :
*       to the operating system.        :
*                                       :
*----------------------------------------

fix_it_up       ==      $580


*----------------------------------------
*                                       :
*       USER-MODE VARIABLE SPACE        :
*       $800..$83F                      :
*                                       :
*       This space reserved for         :
*       applications r== iring          :
*       variable in user RAM.           :
*                                       :
*       Some cartridges (LOGO and       :
*       BASIC, etc.) will use it        :
*       for BSS.                        :
*                                       :
*----------------------------------------

user_vars       ==      $800    ; 64 bytes for carts and things

*___________________________________________________________________________
*** Exception Vectors

evsetsp         ==      $00     ;power-on reset supervisor stack pointer
evsetpc         ==      $04     ;power-on reset initial program counter
buserr          ==      $08     ;bus error
adrerr          ==      $0C     ;address error
illins          ==      $10     ;illegal instruction
zerodiv         ==      $14     ;zero divide
chkinst         ==      $18     ;chk instruction
trapvf          ==      $1C     ;trap on overflow
privldg         ==      $20     ;priviledged instruction
trace           ==      $24     ;trace mode
lin1010         ==      $28     ;line 1010 emulator
lin1111         ==      $2C     ;line 1111 emulator
uninit          ==      $3C     ;uninitialized interrupt vector
spurint         ==      $60     ;spurious interrupt
hblank          ==      $68     ;horizontal blank interrupt
vblank          ==      $70     ;vertical blank interrupt
trap0           ==      $80     ;trap instruction 0
trap1           ==      $84     ;trap instruction 1
trap2           ==      $88     ;trap instruction 2
trap3           ==      $8C     ;trap instruction 3
trap4           ==      $90     ;trap instruction 4
trap5           ==      $94     ;trap instruction 5
trap6           ==      $98     ;trap instruction 7
trap7           ==      $9C     ;trap instruction 7
trap8           ==      $A0     ;trap instruction 8
trap9           ==      $A4     ;trap instruction 9
trap10          ==      $A8     ;trap instruction 10
trap11          ==      $AC     ;trap instruction 11
trap12          ==      $B0     ;trap instruction 12
trap13          ==      $B4     ;trap instruction 13
trap14          ==      $B8     ;trap instruction 14
trap15          ==      $BC     ;trap instruction 15


*************************************************************************
*       interrupt priority table                                        *
*************************************************************************
*                                                                       *
*       priority        vector          description                     *
*       --------        -------         -----------                     *
*       0  low          00_0100 *       centronics busy         i0      *
*       1               00_0104         data carrier detect     i1      *
*       2               00_0108 *       clear-to-send           i2      *
*       3               00_010c         gpu blt done            i3      *
*       4               00_0110         baud rate generator     (d)     *
*       5               00_0114 *       system timer            (c)     *
*       6               00_0118 *       midi/keyboard acia      i4      *
*       7               00_011c         disk dma                i5      *
*       8               00_0120         horizontal blank counter (b)    *
*       9               00_0124 *       tx error                        *
*       10              00_0128 *       tx buffer empty                 *
*       11              00_012c *       receive error                   *
*       12              00_0130 *       receive buffer full             *
*       13              00_0134         user/application timer  (a)     *
*       14              00_0138         ringer indicator        i6      *
*       15 high         00_013c         monochrome detect       i7      *
*************************************************************************

prtint          ==      $100    ;centronics busy                (i0)
dcd232          ==      $104    ;dcd rs-232 interrupt vector    (i1)
cts232          ==      $108    ;cts rs-232 interrupt vector    (i2)
bltdon          ==      $10C    ;graphics blt done interrupt    (i3)
baudrg          ==      $110    ;baud rate generator interrupt  timer d
unused          ==      $114    ;system clock interrupt         timer c
midkey          ==      $118    ;midi/keyboard interrupt        (i4)
dskdma          ==      $11C    ;disk dma interrupt             (i5)
hblnkc          ==      $120    ;horizontal blank counter       timer b
txderr          ==      $124    ;transmitter error interrupt
txbufe          ==      $128    ;transmitter buffer empty interrupt
rxderr          ==      $12C    ;receiver error interrupt
rxbufe          ==      $130    ;receiver buffer full interrupt
sysclk          ==      $134    ;free...free...free...          timer a
rng232          ==      $138    ;ring indicator rs-232          (i6)
monitr          ==      $13C    ;monochrome monitor detect      (i7)
