*__________________________________________________________________________
*** OS Header

ostext		==	$fc0000		; BRA to reset handler
os_version	==	$fc0002		; TOS version number
p_reseth	==	$fc0004		; -> reset handler
os_beg		==	$fc0008		; -> base of OS
os_end		==	$fc000c		; -> end BIOS/GEMDOS/VDI ram usage
os_exec		==	$fc0010		; << unused, reserved >>
os_magic	==	$fc0014		; -> GEM memory usage parm. block
os_date		==	$fc0018		; Date of system build ($YYYYMMDD)
os_conf		==	$fc001c		; OS configuration bits
os_dosdate	==	$fc001e		; DOS-format date of system build

* TOS 1.2+
p_p_root	==	$fc0020		; -> base of OS pool
p_pkbshift	==	$fc0024		; -> keyboard shift state variable
p_p_run		==	$fc0028		; -> GEMDOS PID of currect process
p_p_rsv2	==	$fc002c		; << unused, reserved >>

* pointed to by OS header
reseth		==	$fc0030		; System reset handler
endos		==	$611c		; end of OS memory usage
the_magic	==	$fe81fe		; location of GEM magic number

*__________________________________________________________________________
*** Trap handlers and system vectors

_dksinit	==	$fc16ba		; disk initialization routine
_boot		==	$fc1cc6		; execute boot sector

_prtstat	==	$fc3392		; printer status
_prtvec		==	$fc32f6		; printer output
_auxstat	==	$fc3408		; serial status
_auxvec		==	$fc3422		; serial output

_scrdmp		==	$fc0d0c		; screen dump routine

_rte		==	$fc07a0		; null RTE
_rts		==	$fc0652		; null RTS

_term		==	$fc0b0a
vbl		==	$fc06c0		; vertical blank handler
hbl		==	$fc06aa		; horizontal blank handler
trp13h		==	$fc07ca		; trap #13 handler
trp14h		==	$fc07c4		; trap #14 handler
line1010	==	$fcab3c		; Line-A handler
_critich	==	$fc07c0		; critical error handler
trp14tab	==	$fc084a		; trap #14 vector table
trp13tab	==	$fc0818		; trap #13 vector table
trp1h		==	$fc92d8		; trap #1 handler
trp2h		==	$fdd40a		; trap #2 handler

*__________________________________________________________________________
*** MFP routines

initmfp		==	$fc34fc		; MFP initialization routine
timercint	==	$fc4242		; timer C interrupt handler
aciaexit	==	$fc3b54		; ACIA interrupt exit
sysmidi		==	$fc3f6a		; user MIDI interrupt handler
vecmidi		==	$fc3b12		; system MIDI interrupt handler
vecikbd		==	$fc3b20		; system IKBD interrupt handler
txerror		==	$fc3918		; serial transmit error handler
txrint		==	$fc3890		; serial transmit interrupt handler
rxerror		==	$fc38f8		; serial receive error handler
rcvrint		==	$fc37f2		; serial receive interrupt handler

*__________________________________________________________________________
*** I/O routines

tconstat	==	$fc0978		; table of input status routines
tconin		==	$fc0980		; table of input routines
tcostat		==	$fc0988		; table of output status routines
tconout		==	$fc0990		; table or output routines

* input status routines
_auxistat	==	$fc33a6
constat		==	$fc3494
midstat		==	$fc32a6

* inout routines
_lstin		==	$fc3372
auxin		==	$fc33be
conin		==	$fc34aa
midin		==	$fc32c0

* output status routines
_lstostat	==	$fc3392
_auxostat	==	$fc3408
conoutst	==	$fc34e0
ikbdost		==	$fc326a		; \  These 2 entries are swapped
midiost		==	$fc344a		; /  in the original source code.

* output routines
_lstout		==	$fc32f6
_auxout		==	$fc3422
conout		==	$fca30a
midiwc		==	$fc327a
ikbdwc		==	$fc345c
_asc_out	==	$fca2fe

*__________________________________________________________________________
*** BIOS routines

_get_mpb	==	$fc0a10		; get memory parameter block
bconstat	==	$fc0956		; get input device status
bconin		==	$fc095c		; read a character
bconout		==	$fc0968		; write a character
p_hdv_rw	==	$80000476
_rwabs		==	$fc1a24		; read/write absolute sector
_setexc		==	$fc0a3c		; set exception vector
_tickcal	==	$fc0a54		; get timer calibration
p_hdv_bpb	==	$80000472
_getbpb		==	$fc173c		; get BIOS parameter block
bcostat		==	$fc0962		; get output device status
p_hdv_mediach	==	$8000047e	
_mediach	==	$fc18ec		; return media change status
_drvmap		==	$fc09f8		; get valid drive numbers
_shift		==	$fc09fe		; get keyboard shift status

*__________________________________________________________________________
*** XBIOS routines

initmous	==	$fc40a8		; initialize mouse
_physbase	==	$fc0a5c		; get physical screen base
_logbase	==	$fc0a6c		; get logical screen base
_getrez		==	$fc0a72		; get screen resolution
_setscreen	==	$fc0a7e		; set screen parameters
_setpalette	==	$fc0ac4		; set color palette
_setcolor	==	$fc0acc		; set color register
_floprd		==	$fc0f38		; read floppy disk sector
_flopwr		==	$fc100a		; write floppy disk sector
_flopfmt	==	$fc10c6		; format floppy disk track
_getdsb		==	$fc1732		; get floppy disk DSB (obsolete, returns 0L)
midiws		==	$fc3292		; write string to MIDI
mfpint		==	$fc3754		; set MFP interrupt vector
iorec		==	$fc39fe		; get I/O buffer record
rsconf		==	$fc3a16		; set RS-232 configuration
keytrans	==	$fc41ac		; set keyboard translation
_rand		==	$fc1c76		; get pseudo-random number
_proto_bt	==	$fc1d42		; prototype boot sector
_flopver	==	$fc1286		; verify floppy disk sector
_dumpit		==	$fc0cfa		; perform screen print
_cursconf	==	$fca6c6		; set test cursor configuration
_settime	==	$fc0e4c		; set system/IKBD time
_gettime	==	$fc0e3e		; get system/IKBD time
bioskeys	==	$fc41d8		; restore default keyboard table
ikbdws		==	$fc3480		; write string to IKBD
jdisint		==	$fc377e		; disable MFP interrupt
jenabint	==	$fc37b8		; enable MFP interrupt
giaccess	==	$fc4024		; read/write sound chip
offgibit	==	$fc4082		; clear bit on sound chip
ongibit		==	$fc405c		; set bit on sound chip
xbtimer		==	$fc4172		; set MFP timer
dosound		==	$fc41f2		; start sound interrupt routine
setprt		==	$fc4206		; set printer configuration
ikbdvecs	==	$fc423a		; get IKBD/MIDI vector table
kbrate		==	$fc4218		; set keyboard repeat rate
_prtblk		==	$fc215c		; print graphics block
wvbl		==	$fc07a2		; wait for vertical blank
supexec		==	$fc0950		; execute supervisor routine
puntaes		==	$fc0af0		; remove AES from memory (RAM TOS only)
floprate	==	$fc1692		; set floppy stepping rate
blitmode	==	$fc0e9e		; set blitter configuration
